- Add partition table struct to be used to parse partition table in flash.
- Add JFFS2 as a type, and add readoly flag.
- Improve some comments.
- Lindent has been run, fixing whitespace and formatting issues.

Signed-off-by: Jesper Nilsson <[EMAIL PROTECTED]>
---
 include/asm-cris/axisflashmap.h |   39 +++++++++++++++++++++++++++------------
 1 files changed, 27 insertions(+), 12 deletions(-)

diff --git a/include/asm-cris/axisflashmap.h b/include/asm-cris/axisflashmap.h
index 7a8d311..015ca54 100644
--- a/include/asm-cris/axisflashmap.h
+++ b/include/asm-cris/axisflashmap.h
@@ -10,23 +10,23 @@
  */
 
 #define PARTITION_TABLE_OFFSET 10
-#define PARTITION_TABLE_MAGIC 0xbeef /* Not a good magic */
+#define PARTITION_TABLE_MAGIC 0xbeef   /* Not a good magic */
 
 /* The partitiontable_head is located at offset +10: */
 struct partitiontable_head {
-       __u16 magic; /* PARTITION_TABLE_MAGIC */ 
-       __u16 size;  /* Length of ptable block (not header) */
-       __u32 checksum; /* simple longword sum */
+       __u16 magic;    /* PARTITION_TABLE_MAGIC */
+       __u16 size;     /* Length of ptable block (entries + end marker) */
+       __u32 checksum; /* simple longword sum, over entries + end marker  */
 };
 
 /* And followed by partition table entries */
 struct partitiontable_entry {
-       __u32 offset;   /* Offset is relative to the sector the ptable is in */
-       __u32 size;
-       __u32 checksum; /* simple longword sum */
-       __u16 type;
-       __u16 flags;   /* bit 0: ro/rw = 1/0 */
-       __u32 future0; /* 16 bytes reserved for future use */
+       __u32 offset;           /* relative to the sector the ptable is in */
+       __u32 size;             /* in bytes */
+       __u32 checksum;         /* simple longword sum */
+       __u16 type;             /* see type codes below */
+       __u16 flags;            /* bit 0: ro/rw = 1/0 */
+       __u32 future0;          /* 16 bytes reserved for future use */
        __u32 future1;
        __u32 future2;
        __u32 future3;
@@ -35,12 +35,27 @@ struct partitiontable_entry {
 #define PARTITIONTABLE_END_MARKER 0xFFFFFFFF
 #define PARTITIONTABLE_END_MARKER_SIZE 4
 
-/*#define PARTITION_TYPE_RESCUE 0x0000?*/  /* Not used, maybe it should? */
+#define PARTITIONTABLE_END_PAD 10
+
+/* Complete structure for whole partition table */
+/* note that table may end before CONFIG_ETRAX_PTABLE_ENTRIES by setting
+ * offset of the last entry + 1 to PARTITIONTABLE_END_MARKER.
+ */
+struct partitiontable {
+       __u8 skip[PARTITION_TABLE_OFFSET];
+       struct partitiontable_head head;
+       struct partitiontable_entry entries[];
+};
+
 #define PARTITION_TYPE_PARAM  0x0001
 #define PARTITION_TYPE_KERNEL 0x0002
 #define PARTITION_TYPE_JFFS   0x0003
+#define PARTITION_TYPE_JFFS2  0x0000
+
+#define        PARTITION_FLAGS_READONLY_MASK   0x0001
+#define        PARTITION_FLAGS_READONLY        0x0001
 
 /* The master mtd for the entire flash. */
-extern struct mtd_info* axisflash_mtd;
+extern struct mtd_info *axisflash_mtd;
 
 #endif
-- 
1.5.3.6.970.gd25430

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to